@@ -22,6 +22,150 @@ from ._jsii import *
 import ros_cdk_core
 
 
+class Account(
+    ros_cdk_core.Resource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@alicloud/ros-cdk-adb.Account",
+):
+    '''A ROS resource type:  ``ALIYUN::ADB::Account``.'''
+
+    def __init__(
+        self,
+        scope: ros_cdk_core.Construct,
+        id: builtins.str,
+        props: "AccountProps",
+        enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''Create a new ``ALIYUN::ADB::Account``.
+
+        Param scope - scope in which this resource is defined
+        Param id    - scoped id of the resource
+        Param props - resource properties
+
+        :param scope: -
+        :param id: -
+        :param props: -
+        :param enable_resource_property_constraint: -
+        '''
+        jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrAccountName")
+    def attr_account_name(self) -> ros_cdk_core.IResolvable:
+        '''Attribute AccountName: The name of the account.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrAccountName"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrAccountType")
+    def attr_account_type(self) -> ros_cdk_core.IResolvable:
+        '''Attribute AccountType: The type of the account.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrAccountType"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrDbClusterId")
+    def attr_db_cluster_id(self) -> ros_cdk_core.IResolvable:
+        '''Attribute DBClusterId: The ID of the cluster.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDbClusterId"))
+
+
+@jsii.data_type(
+    jsii_type="@alicloud/ros-cdk-adb.AccountProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "account_name": "accountName",
+        "account_password": "accountPassword",
+        "db_cluster_id": "dbClusterId",
+        "account_description": "accountDescription",
+        "account_type": "accountType",
+    },
+)
+class AccountProps:
+    def __init__(
+        self,
+        *,
+        account_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        account_password: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        db_cluster_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        account_description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        account_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+    ) -> None:
+        '''Properties for defining a ``ALIYUN::ADB::Account``.
+
+        :param account_name: Property accountName: The name of the account.
+        :param account_password: Property accountPassword: The password of the account. The password must contain uppercase letters, lowercase letters, digits, and special characters. Special characters include ! @ # $ % ^ & * () _ + - and = The password must be 8 to 32 characters in length.
+        :param db_cluster_id: Property dbClusterId: The ID of the cluster.
+        :param account_description: Property accountDescription: The description of the account. The description cannot start with http://or https://. The description can be up to 256 characters in length.
+        :param account_type: Property accountType: Normal: standard account Super: privileged account.
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "account_name": account_name,
+            "account_password": account_password,
+            "db_cluster_id": db_cluster_id,
+        }
+        if account_description is not None:
+            self._values["account_description"] = account_description
+        if account_type is not None:
+            self._values["account_type"] = account_type
+
+    @builtins.property
+    def account_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''Property accountName: The name of the account.'''
+        result = self._values.get("account_name")
+        assert result is not None, "Required property 'account_name' is missing"
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+    @builtins.property
+    def account_password(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''Property accountPassword: The password of the account.
+
+        The password must contain uppercase letters, lowercase letters, digits, and special
+        characters.
+        Special characters include ! @ # $ % ^ & * ()  _ + - and =
+        The password must be 8 to 32 characters in length.
+        '''
+        result = self._values.get("account_password")
+        assert result is not None, "Required property 'account_password' is missing"
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+    @builtins.property
+    def db_cluster_id(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''Property dbClusterId: The ID of the cluster.'''
+        result = self._values.get("db_cluster_id")
+        assert result is not None, "Required property 'db_cluster_id' is missing"
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+    @builtins.property
+    def account_description(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property accountDescription: The description of the account.
+
+        The description cannot start with http://or https://.
+        The description can be up to 256 characters in length.
+        '''
+        result = self._values.get("account_description")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+    @builtins.property
+    def account_type(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property accountType: Normal: standard account Super: privileged account.'''
+        result = self._values.get("account_type")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "AccountProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class DBCluster(
     ros_cdk_core.Resource,
     metaclass=jsii.JSIIMeta,
@@ -88,6 +232,7 @@ class DBCluster(
         "period": "period",
         "period_type": "periodType",
         "resource_group_id": "resourceGroupId",
+        "tags": "tags",
         "zone_id": "zoneId",
     },
 )
@@ -111,6 +256,7 @@ class DBClusterProps:
         period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
         period_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        tags: typing.Optional[typing.Sequence["RosDBCluster.TagsProperty"]] = None,
         zone_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::ADB::DBCluster``.
@@ -131,6 +277,7 @@ class DBClusterProps:
         :param period: Property period: Valid values when the Period parameter is set to Month: 1, 2, 3, 4, 5, 6, 7, 8, and 9. Valid values when the Period parameter is set to Year: 1, 2, and 3.
         :param period_type: Property periodType: The subscription period for the cluster. This parameter is required if the PayType parameter is set to Prepaid. Valid values: Year: subscription on a yearly basis Month: subscription on a monthly basis
         :param resource_group_id: Property resourceGroupId: The ID of the resource group.
+        :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         :param zone_id: Property zoneId: The zone ID of the cluster. You can call the DescribeRegions operation to query the most recent zone list.
         '''
         self._values: typing.Dict[str, typing.Any] = {
@@ -161,6 +308,8 @@ class DBClusterProps:
             self._values["period_type"] = period_type
         if resource_group_id is not None:
             self._values["resource_group_id"] = resource_group_id
+        if tags is not None:
+            self._values["tags"] = tags
         if zone_id is not None:
             self._values["zone_id"] = zone_id
 
@@ -339,6 +488,15 @@ class DBClusterProps:
         result = self._values.get("resource_group_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List["RosDBCluster.TagsProperty"]]:
+        '''Property tags: Tags to attach to instance.
+
+        Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.List["RosDBCluster.TagsProperty"]], result)
+
     @builtins.property
     def zone_id(
         self,
@@ -362,6 +520,299 @@ class DBClusterProps:
         )
 
 
+class RosAccount(
+    ros_cdk_core.RosResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@alicloud/ros-cdk-adb.RosAccount",
+):
+    '''A ROS template type:  ``ALIYUN::ADB::Account``.'''
+
+    def __init__(
+        self,
+        scope: ros_cdk_core.Construct,
+        id: builtins.str,
+        props: "RosAccountProps",
+        enable_resource_property_constraint: builtins.bool,
+    ) -> None:
+        '''Create a new ``ALIYUN::ADB::Account``.
+
+        :param scope: - scope in which this resource is defined.
+        :param id: - scoped id of the resource.
+        :param props: - resource properties.
+        :param enable_resource_property_constraint: -
+        '''
+        jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
+
+    @jsii.member(jsii_name="renderProperties")
+    def _render_properties(
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
+        '''
+        :param props: -
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
+
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
+    def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrAccountName")
+    def attr_account_name(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: AccountName: The name of the account.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrAccountName"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrAccountType")
+    def attr_account_type(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: AccountType: The type of the account.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrAccountType"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrDbClusterId")
+    def attr_db_cluster_id(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: DBClusterId: The ID of the cluster.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDbClusterId"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="rosProperties")
+    def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="accountName")
+    def account_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''
+        :Property: accountName: The name of the account.
+        '''
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "accountName"))
+
+    @account_name.setter
+    def account_name(
+        self,
+        value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+    ) -> None:
+        jsii.set(self, "accountName", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="accountPassword")
+    def account_password(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''
+        ::
+
+
+
+        $ % ^ & * ()  _ + - and =
+
+        The password must be 8 to 32 characters in length.
+        :Property:
+
+        accountPassword: The password of the account.
+        The password must contain uppercase letters, lowercase letters, digits, and special
+        characters.
+        Special characters include !
+        '''
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "accountPassword"))
+
+    @account_password.setter
+    def account_password(
+        self,
+        value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+    ) -> None:
+        jsii.set(self, "accountPassword", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="dbClusterId")
+    def db_cluster_id(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''
+        :Property: dbClusterId: The ID of the cluster.
+        '''
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "dbClusterId"))
+
+    @db_cluster_id.setter
+    def db_cluster_id(
+        self,
+        value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+    ) -> None:
+        jsii.set(self, "dbClusterId", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="enableResourcePropertyConstraint")
+    def enable_resource_property_constraint(self) -> builtins.bool:
+        return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
+
+    @enable_resource_property_constraint.setter
+    def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        jsii.set(self, "enableResourcePropertyConstraint", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="accountDescription")
+    def account_description(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property:
+
+        accountDescription: The description of the account.
+        The description cannot start with http://or https://.
+        The description can be up to 256 characters in length.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "accountDescription"))
+
+    @account_description.setter
+    def account_description(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "accountDescription", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="accountType")
+    def account_type(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property:
+
+        accountType: Normal: standard account
+        Super: privileged account
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "accountType"))
+
+    @account_type.setter
+    def account_type(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "accountType", value)
+
+
+@jsii.data_type(
+    jsii_type="@alicloud/ros-cdk-adb.RosAccountProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "account_name": "accountName",
+        "account_password": "accountPassword",
+        "db_cluster_id": "dbClusterId",
+        "account_description": "accountDescription",
+        "account_type": "accountType",
+    },
+)
+class RosAccountProps:
+    def __init__(
+        self,
+        *,
+        account_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        account_password: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        db_cluster_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        account_description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        account_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+    ) -> None:
+        '''Properties for defining a ``ALIYUN::ADB::Account``.
+
+        :param account_name: 
+        :param account_password: 
+        :param db_cluster_id: 
+        :param account_description: 
+        :param account_type: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "account_name": account_name,
+            "account_password": account_password,
+            "db_cluster_id": db_cluster_id,
+        }
+        if account_description is not None:
+            self._values["account_description"] = account_description
+        if account_type is not None:
+            self._values["account_type"] = account_type
+
+    @builtins.property
+    def account_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''
+        :Property: accountName: The name of the account.
+        '''
+        result = self._values.get("account_name")
+        assert result is not None, "Required property 'account_name' is missing"
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+    @builtins.property
+    def account_password(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''
+        ::
+
+
+
+        $ % ^ & * ()  _ + - and =
+
+        The password must be 8 to 32 characters in length.
+        :Property:
+
+        accountPassword: The password of the account.
+        The password must contain uppercase letters, lowercase letters, digits, and special
+        characters.
+        Special characters include !
+        '''
+        result = self._values.get("account_password")
+        assert result is not None, "Required property 'account_password' is missing"
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+    @builtins.property
+    def db_cluster_id(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+        '''
+        :Property: dbClusterId: The ID of the cluster.
+        '''
+        result = self._values.get("db_cluster_id")
+        assert result is not None, "Required property 'db_cluster_id' is missing"
+        return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+    @builtins.property
+    def account_description(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property:
+
+        accountDescription: The description of the account.
+        The description cannot start with http://or https://.
+        The description can be up to 256 characters in length.
+        '''
+        result = self._values.get("account_description")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+    @builtins.property
+    def account_type(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property:
+
+        accountType: Normal: standard account
+        Super: privileged account
+        '''
+        result = self._values.get("account_type")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "RosAccountProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class RosDBCluster(
     ros_cdk_core.RosResource,
     metaclass=jsii.JSIIMeta,
@@ -740,6 +1191,21 @@ class RosDBCluster(
     ) -> None:
         jsii.set(self, "resourceGroupId", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> typing.Optional[typing.List["RosDBCluster.TagsProperty"]]:
+        '''
+        :Property: tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        return typing.cast(typing.Optional[typing.List["RosDBCluster.TagsProperty"]], jsii.get(self, "tags"))
+
+    @tags.setter
+    def tags(
+        self,
+        value: typing.Optional[typing.List["RosDBCluster.TagsProperty"]],
+    ) -> None:
+        jsii.set(self, "tags", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="zoneId")
     def zone_id(
@@ -757,6 +1223,58 @@ class RosDBCluster(
     ) -> None:
         jsii.set(self, "zoneId", value)
 
+    @jsii.data_type(
+        jsii_type="@alicloud/ros-cdk-adb.RosDBCluster.TagsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class TagsProperty:
+        def __init__(
+            self,
+            *,
+            key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        ) -> None:
+            '''
+            :param key: 
+            :param value: 
+            '''
+            self._values: typing.Dict[str, typing.Any] = {
+                "key": key,
+            }
+            if value is not None:
+                self._values["value"] = value
+
+        @builtins.property
+        def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+            '''
+            :Property: key: undefined
+            '''
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+        @builtins.property
+        def value(
+            self,
+        ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+            '''
+            :Property: value: undefined
+            '''
+            result = self._values.get("value")
+            return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "TagsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-adb.RosDBClusterProps",
@@ -778,6 +1296,7 @@ class RosDBCluster(
         "period": "period",
         "period_type": "periodType",
         "resource_group_id": "resourceGroupId",
+        "tags": "tags",
         "zone_id": "zoneId",
     },
 )
@@ -801,6 +1320,7 @@ class RosDBClusterProps:
         period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
         period_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        tags: typing.Optional[typing.Sequence[RosDBCluster.TagsProperty]] = None,
         zone_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::ADB::DBCluster``.
@@ -821,6 +1341,7 @@ class RosDBClusterProps:
         :param period: 
         :param period_type: 
         :param resource_group_id: 
+        :param tags: 
         :param zone_id: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
@@ -851,6 +1372,8 @@ class RosDBClusterProps:
             self._values["period_type"] = period_type
         if resource_group_id is not None:
             self._values["resource_group_id"] = resource_group_id
+        if tags is not None:
+            self._values["tags"] = tags
         if zone_id is not None:
             self._values["zone_id"] = zone_id
 
@@ -1052,6 +1575,14 @@ class RosDBClusterProps:
         result = self._values.get("resource_group_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List[RosDBCluster.TagsProperty]]:
+        '''
+        :Property: tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.List[RosDBCluster.TagsProperty]], result)
+
     @builtins.property
     def zone_id(
         self,
@@ -1075,8 +1606,12 @@ class RosDBClusterProps:
 
 
 __all__ = [
+    "Account",
+    "AccountProps",
     "DBCluster",
     "DBClusterProps",
+    "RosAccount",
+    "RosAccountProps",
     "RosDBCluster",
     "RosDBClusterProps",
 ]
